@@ -312,43 +312,6 @@ class ContractFunding:
             return self.fee_oracleUnits_to_maker
         return self.fee_oracleUnits_to_taker
 
-    ###############
-    # Specialized calculations
-    ###############
-    def effective_adjusted_price_oracleUnits_per_bch(self, role: Role) -> float:
-        # The direction of price adjustment depends on which side is maker/taker.
-        # Without context, positive fees will cause the formula to push the price up.
-        # However, in context, the higher initial effective price benefits a hedge
-        # maker specifically. Therefore, when the maker is long, we need to reverse
-        # the direction of the fees so that the benefit always goes to the maker.
-        #
-        # Unfortunately, the convention of most of the code is "fees to"
-        # instead of "fees from" which the original equation was created with.
-        # Therefore, there is an extra -1 causing directionality to look reversed:
-        direction = 1
-        if self.base_proposal.maker_side == Side.HEDGE:
-            direction = -1
-
-        # The calculation is not especially intuitive. Here is the breakdown:
-        # Naming:
-        # nominal units = u
-        # fees paid in bch = fP = Σ(fP1...fPm)
-        # fees received in bch = fR = Σ(fR1...fRn)
-        # original price = pS
-        # adjusted price = pA
-        #
-        # (fP - fR) = u (1/pS - 1/pA)
-        # (fP - fR)/u = 1/pS - 1/pA
-        # 1/pA = 1/pS - (fP - fR)/u
-        # 1/pA = (u - pS(fP - fR)) / (u pS)
-        # pA = u pS / (u - pS(fP - fR))
-
-        u = self.base_proposal.hedge_input_oracleUnits
-        pS = float(self.base_proposal.start_price_oracleUnits_per_bch)
-        total_fees_to_role_bch = direction * aggregate_fee_sats_to_role(self.fee_agreements, role).bch
-        adjusted_price_oracleUnits_per_bch = u * pS / (u - pS * total_fees_to_role_bch)
-        return adjusted_price_oracleUnits_per_bch
-
     ###############
     # Actions
     ###############
