@@ -7,7 +7,6 @@ from arrow import Arrow
 # Local imports
 from .bch_primitives import (
     SATS_PER_BCH,
-    PublicKey,
     Sats,
     ScriptTimestamp,
     UtxoSats,
@@ -89,7 +88,6 @@ def standard_contract_proposal(
     nominal_oracleUnits: OracleUnit = NOMINAL_USDEM2,
     long_leverage: LongLeverage = LONG_LEVERAGE,
     start_price_oracleUnits_per_bch: ScriptPriceInOracleUnitsPerBch = START_PRICE_USDEM2_PER_BCH,
-    oracle_public_key: PublicKey = NOMINAL_USDEM2.public_key,
     maker_side: Side = Side.HEDGE,
 ) -> ContractProposal:
     return ContractProposal.new_from_intent(
@@ -218,65 +216,6 @@ def standard_contract_funding(proposal: ContractProposal | None = None) -> Contr
 
 
 class TestContractFundingDerivedValues(unittest.TestCase):
-    def test_effective_adjusted_price_when_maker_is_hedge(self):
-        # See the implementation for explanation of the formula
-        # base values
-        funding = standard_contract_funding()
-        u = funding.base_proposal.hedge_input_oracleUnits
-        pS = float(funding.base_proposal.start_price_oracleUnits_per_bch)
-
-        # in the context of long taker
-        fP = -TOTAL_FEES_TO_TAKER_SATS.bch
-        fR = 0.0
-        expected_adjusted_price_for_taker = u * pS / (u - pS * (fP - fR))
-        adjusted_price_for_taker = funding.effective_adjusted_price_oracleUnits_per_bch(Role.TAKER)
-        self.assertAlmostEqual(adjusted_price_for_taker, expected_adjusted_price_for_taker)
-
-        # in the context of hedge maker
-        fP = 0.0
-        fR = +TOTAL_FEES_TO_MAKER_SATS.bch
-        expected_adjusted_price_for_maker = u * pS / (u - pS * (fP - fR))
-        adjusted_price_for_maker = funding.effective_adjusted_price_oracleUnits_per_bch(Role.MAKER)
-        self.assertAlmostEqual(adjusted_price_for_maker, expected_adjusted_price_for_maker)
-
-        # Sanity check that maker and taker with different views on the fees
-        # have different apparent adjusted prices
-        self.assertNotEqual(expected_adjusted_price_for_taker, expected_adjusted_price_for_maker)
-
-        # Sanity check that the result prices are close to the original price
-        one_percent_of_original_price = 0.05 * pS
-        self.assertAlmostEqual(adjusted_price_for_taker, pS, delta=one_percent_of_original_price)
-        self.assertAlmostEqual(adjusted_price_for_maker, pS, delta=one_percent_of_original_price)
-
-    def test_effective_adjusted_price_when_maker_is_long(self):
-        # base values
-        funding = standard_contract_funding(standard_contract_proposal(maker_side=Side.LONG))
-        u = funding.base_proposal.hedge_input_oracleUnits
-        pS = float(funding.base_proposal.start_price_oracleUnits_per_bch)
-
-        # in the context of hedge taker
-        fP = +TOTAL_FEES_TO_TAKER_SATS.bch
-        fR = 0.0
-        expected_adjusted_price_for_taker = u * pS / (u - pS * (fP - fR))
-        adjusted_price_for_taker = funding.effective_adjusted_price_oracleUnits_per_bch(Role.TAKER)
-        self.assertAlmostEqual(adjusted_price_for_taker, expected_adjusted_price_for_taker)
-
-        # in the context of long maker
-        fP = 0.0
-        fR = -TOTAL_FEES_TO_MAKER_SATS.bch
-        expected_adjusted_price_for_maker = u * pS / (u - pS * (fP - fR))
-        adjusted_price_for_maker = funding.effective_adjusted_price_oracleUnits_per_bch(Role.MAKER)
-        self.assertAlmostEqual(adjusted_price_for_maker, expected_adjusted_price_for_maker)
-
-        # Sanity check that maker and taker with different views on the fees
-        # have different apparent adjusted prices
-        self.assertNotEqual(expected_adjusted_price_for_taker, expected_adjusted_price_for_maker)
-
-        # Sanity check that the result prices are close to the original price
-        one_percent_of_original_price = 0.05 * pS
-        self.assertAlmostEqual(adjusted_price_for_taker, pS, delta=one_percent_of_original_price)
-        self.assertAlmostEqual(adjusted_price_for_maker, pS, delta=one_percent_of_original_price)
-
     def test_fee_sats_to_side(self):
         # Confirm hedge maker and long taker
         hedge_maker_contract = standard_contract_funding(standard_contract_proposal(maker_side=Side.HEDGE))
